@@ -1,7 +1,12 @@
 import json
-import requests
+import uuid
 
+import requests
+import pickle
+import pandas
 from .request import Request
+from .mlmodel import MLModel
+
 
 class WizataDSAPIClient:
 
@@ -27,7 +32,7 @@ class WizataDSAPIClient:
         else:
             response = requests.post(self.__url() + route, headers=self.__header(), json=content_json)
             if response.status_code == 200:
-                return response
+                return response.content
             else:
                 raise RuntimeError(str(response.status_code) + " - " + response.reason)
 
@@ -37,5 +42,13 @@ class WizataDSAPIClient:
     def get_ds_functions(self):
         return self.__request_process("GET", "get_ds_functions")
 
-    def get_datas(self, query: Request):
-        return self.__request_process("POST", "get_datas", json.dumps(query.prepare()))
+    def get_models(self):
+        json_models = self.__request_process("GET", "get_models")
+        ml_models = []
+        for json_model in json_models:
+            ml_models.append(MLModel(uuid.UUID(json_model["model_id"])))
+        return ml_models
+
+    def get_datas(self, query: Request) -> pandas.DataFrame:
+        df_bytes = self.__request_process("POST", "get_datas", query.prepare())
+        return pickle.loads(df_bytes)
